@@ -1,10 +1,8 @@
 package Class::Usul::Functions;
 
-use 5.010001;
 use strict;
 use warnings;
-use feature 'state';
-use parent  'Exporter::Tiny';
+use parent 'Exporter::Tiny';
 
 use Class::Inspector;
 use Class::Null;
@@ -21,7 +19,6 @@ use Digest::MD5                qw( md5 );
 use English                    qw( -no_match_vars );
 use Fcntl                      qw( F_SETFL O_NONBLOCK );
 use File::Basename             qw( basename dirname );
-use File::DataClass::Constants qw( CYGWIN MSOFT );
 use File::DataClass::Functions qw( supported_extensions );
 use File::DataClass::IO        qw( );
 use File::HomeDir              qw( );
@@ -36,28 +33,30 @@ use Unexpected::Functions      qw( is_class_loaded PathAlreadyExists
                                    PathNotFound Tainted Unspecified );
 use User::pwent;
 
-our @EXPORT_OK   = qw( abs_path app_prefix arg_list assert
-                       assert_directory base64_decode_ns
-                       base64_encode_ns bsonid bsonid_time bson64id
-                       bson64id_time build canonicalise class2appdir classdir
-                       classfile create_token curry dash2under data_dumper
-                       digest distname elapsed emit emit_err emit_to
-                       ensure_class_loaded env_prefix escape_TT
-                       exception find_apphome find_source first_char fold fqdn
-                       fullname get_cfgfiles get_user hex2str
-                       home2appldir io is_arrayref is_coderef
-                       is_hashref is_member is_win32 list_attr_of loginid
-                       logname merge_attributes my_prefix
-                       nonblocking_write_pipe_pair pad
-                       prefix2class product socket_pair
-                       split_on__ split_on_dash squeeze strip_leader sub_name
-                       sum symlink thread_id throw throw_on_error trim
-                       unescape_TT untaint_cmdline untaint_identifier
-                       untaint_path untaint_string urandom uuid whiten zip );
+our @EXPORT_OK   = qw( abs_path app_prefix arg_list assert assert_directory
+                       base64_decode_ns base64_encode_ns bsonid bsonid_time
+                       bson64id bson64id_time build canonicalise chain
+                       class2appdir classdir classfile create_token curry cwdp
+                       dash2under data_dumper digest distname elapsed emit
+                       emit_err emit_to ensure_class_loaded env_prefix
+                       escape_TT exception find_apphome find_source first_char
+                       fold fqdn fullname get_cfgfiles get_user hex2str
+                       home2appldir io is_arrayref is_coderef is_hashref
+                       is_member is_win32 list_attr_of loginid logname
+                       merge_attributes my_prefix nonblocking_write_pipe_pair
+                       pad prefix2class product socket_pair split_on__
+                       split_on_dash squeeze strip_leader sub_name sum symlink
+                       thread_id throw throw_on_error trim unescape_TT
+                       untaint_cmdline untaint_identifier untaint_path
+                       untaint_string urandom uuid whiten zip );
 our %EXPORT_REFS =   ( assert => sub { ASSERT }, );
 our %EXPORT_TAGS =   ( all    => [ @EXPORT_OK ], );
 
-my $BSON_Id_Inc : shared = 0;
+# Package variables
+my $bson_id_count : shared = 0;
+my $bson2_id_count  = 0;
+my $bson2_prev_time = 0;
+my $digest_cache;
 
 # Private functions
 my $_base64_char_set = sub {
@@ -65,20 +64,21 @@ my $_base64_char_set = sub {
 };
 
 my $_bsonid_inc = sub {
-   my ($now, $version) = @_; state $id_inc //= 0; state $prev_time //= 0;
+   my ($now, $version) = @_;
 
-   $version or return substr pack( 'N', $BSON_Id_Inc++ % 0xFFFFFF ), 1, 3;
+   $version or return substr pack( 'N', $bson_id_count++ % 0xFFFFFF ), 1, 3;
 
-   $id_inc++; $now > $prev_time and $id_inc = 0; $prev_time = $now;
+   $bson2_id_count++; $now > $bson2_prev_time and $bson2_id_count = 0;
+   $bson2_prev_time = $now;
 
    $version < 2 and return (substr pack( 'n', thread_id() % 0xFF ), 1, 1)
-                          .(pack 'n', $id_inc % 0xFFFF);
+                          .(pack 'n', $bson2_id_count % 0xFFFF);
 
    $version < 3 and return (pack 'n', thread_id() % 0xFFFF )
-                          .(pack 'n', $id_inc % 0xFFFF);
+                          .(pack 'n', $bson2_id_count % 0xFFFF);
 
    return (pack 'n', thread_id() % 0xFFFF )
-         .(substr pack( 'N', $id_inc % 0xFFFFFF ), 1, 3);
+         .(substr pack( 'N', $bson2_id_count % 0xFFFFFF ), 1, 3);
 };
 
 my $_bsonid_time = sub {
@@ -120,7 +120,7 @@ my $_get_pod_content_for_attr = sub {
       $ev and $ev->{type} eq 'text' and $pod = $ev->{content} and last;
    }
 
-   $pod ||= 'Undocumented'; chomp $pod; $pod =~ s{ [\n] }{ }gmx;
+   $pod //= 'Undocumented'; chomp $pod; $pod =~ s{ [\n] }{ }gmx;
 
    $pod = squeeze( $pod ); $pod =~ m{ \A (.+) \z }msx and $pod = $1;
 
@@ -156,7 +156,7 @@ my $_bsonid = sub {
    my $now     = time;
    my $time    = $_bsonid_time->( $now, $version );
    my $host    = substr md5( hostname ), 0, 3;
-   my $pid     = pack 'n', $$ % 0xFFFF;
+   my $pid     = pack 'n', $PID % 0xFFFF;
 
    return $time.$host.$pid.$_bsonid_inc->( $now, $version );
 };
@@ -166,7 +166,7 @@ my $_find_cfg_in_inc = sub {
 
    for my $dir (grep { defined and -d $_ }
                 map  { abs_path( catdir( $_, $classdir ) ) } @INC) {
-      for my $extn (@{ $extns || [ supported_extensions() ] }) {
+      for my $extn (@{ $extns // [ supported_extensions() ] }) {
          my $path = $_catpath->( $dir, $file.$extn );
 
          -f $path and return dirname( $path );
@@ -200,7 +200,7 @@ my $_get_file_var = sub {
 };
 
 my $_get_known_file_var = sub {
-   my ($appname, $classdir) = @_; $appname || return;
+   my ($appname, $classdir) = @_; length $appname or return;
 
    my $path; $path = $_read_variable->( DEFAULT_ENVDIR(), $appname, 'APPLDIR' )
          and $path = catdir( $path, 'lib', $classdir );
@@ -227,11 +227,12 @@ sub abs_path ($) {
    $v = Cwd::abs_path( untaint_path( $v ) );
 
    is_win32() and defined $v and $v =~ s{ / }{\\}gmx; # More hate
+
    return $v;
 }
 
 sub app_prefix ($) {
-   (my $v = lc ($_[ 0 ] || q())) =~ s{ :: }{_}gmx; return $v;
+   (my $v = lc ($_[ 0 ] // q())) =~ s{ :: }{_}gmx; return $v;
 }
 
 sub arg_list (;@) {
@@ -241,9 +242,11 @@ sub arg_list (;@) {
 }
 
 sub assert_directory ($) {
-   my $v = abs_path( $_[ 0 ] ); (defined $v and length $v) or return $v;
+   my $v = abs_path( $_[ 0 ] );
 
-   return -d "${v}" ? untaint_path( $v ) : undef;
+   defined $v and length $v and -d "${v}" and return $v;
+
+   return;
 }
 
 sub base64_decode_ns ($) {
@@ -328,7 +331,7 @@ sub bson64id_time ($) {
 }
 
 sub build (&;$) {
-   my $code = shift; my $f = shift || sub {}; return sub { $code->( $f->() ) };
+   my $code = shift; my $f = shift // sub {}; return sub { $code->( $f->() ) };
 }
 
 sub canonicalise ($;$) {
@@ -345,12 +348,16 @@ sub canonicalise ($;$) {
    return canonpath( untaint_path( catfile( $base, @relpath ) ) );
 }
 
+sub chain (;@) {
+   return (fold( sub { my ($x, $y) = @_; $x->$y })->( shift ))->( @_ );
+}
+
 sub class2appdir ($) {
    return lc distname( $_[ 0 ] );
 }
 
 sub classdir ($) {
-   return catdir( split m{ :: }mx, $_[ 0 ] || q() );
+   return catdir( split m{ :: }mx, $_[ 0 ] // q() );
 }
 
 sub classfile ($) {
@@ -365,6 +372,10 @@ sub curry (&$;@) {
    my ($code, @args) = @_; return sub { $code->( @args, @_ ) };
 }
 
+sub cwdp () {
+   return abs_path( curdir );
+}
+
 sub dash2under (;$) {
   (my $v = $_[ 0 ] // q()) =~ s{ [\-] }{_}gmx; return $v;
 }
@@ -374,15 +385,16 @@ sub data_dumper (;@) {
 }
 
 sub digest ($) {
-   my $seed = shift; my ($candidate, $digest); state $cache;
+   my $seed = shift; my ($candidate, $digest);
 
-   if ($cache) { $digest = Digest->new( $cache ) }
+   if ($digest_cache) { $digest = Digest->new( $digest_cache ) }
    else {
       for (DIGEST_ALGORITHMS) {
          $candidate = $_; $digest = eval { Digest->new( $candidate ) } and last;
       }
 
-      $digest or throw( 'Digest algorithm not found' ); $cache = $candidate;
+      $digest or throw( 'Digest algorithm not found' );
+      $digest_cache = $candidate;
    }
 
    $digest->add( $seed );
@@ -391,7 +403,7 @@ sub digest ($) {
 }
 
 sub distname ($) {
-   (my $v = $_[ 0 ] || q()) =~ s{ :: }{-}gmx; return $v;
+   (my $v = $_[ 0 ] // q()) =~ s{ :: }{-}gmx; return $v;
 }
 
 #head2 downgrade
@@ -402,7 +414,7 @@ sub distname ($) {
 #the input scalar to the output scalar but resets the output scalar
 #type to C<PV>
 #sub downgrade (;$) {
-#   my $x = shift || q(); my ($y) = $x =~ m{ (.*) }msx; return $y;
+#   my $x = shift // q(); my ($y) = $x =~ m{ (.*) }msx; return $y;
 #}
 
 sub elapsed () {
@@ -532,13 +544,13 @@ sub fold (&) {
 }
 
 sub fqdn (;$) {
-   my $x = shift || hostname; return (gethostbyname( $x ))[ 0 ];
+   my $x = shift // hostname; return (gethostbyname( $x ))[ 0 ];
 }
 
 sub fullname () {
-   my $v = (split m{ \s* , \s * }msx, (get_user()->gecos || q()))[ 0 ];
+   my $v = (split m{ \s* , \s * }msx, (get_user()->gecos // q()))[ 0 ];
 
-   $v ||= q(); $v =~ s{ [\&] }{}gmx; # Coz af25e158-d0c7-11e3-bdcb-31d9eda79835
+   $v //= q(); $v =~ s{ [\&] }{}gmx; # Coz af25e158-d0c7-11e3-bdcb-31d9eda79835
 
    return untaint_cmdline( $v );
 }
@@ -552,11 +564,11 @@ sub get_cfgfiles ($;$$) {
    my $app_pref = app_prefix   $appclass;
    my $appdir   = class2appdir $appclass;
    my $env_pref = env_prefix   $appclass;
-   my $suffix   = $ENV{ "${env_pref}_CONFIG_LOCAL_SUFFIX" } || '_local';
+   my $suffix   = $ENV{ "${env_pref}_CONFIG_LOCAL_SUFFIX" } // '_local';
    my @paths    = ();
 
    for my $dir (@{ $dirs }) {
-      for my $extn (@{ $extns || [ supported_extensions() ] }) {
+      for my $extn (@{ $extns // [ supported_extensions() ] }) {
          for my $path (map { $_catpath->( $dir, $_ ) } "${app_pref}${extn}",
                        "${appdir}${extn}", "${app_pref}${suffix}${extn}",
                        "${appdir}${suffix}${extn}") {
@@ -617,11 +629,11 @@ sub is_member (;@) {
 }
 
 sub is_ntfs  () {
-   return is_win32() || lc $OSNAME eq CYGWIN ? 1 : 0;
+   return is_win32() || lc $OSNAME eq 'cygwin' ? 1 : 0;
 }
 
 sub is_win32 () {
-   return lc $OSNAME eq MSOFT ? 1 : 0;
+   return lc $OSNAME eq 'mswin32' ? 1 : 0;
 }
 
 sub list_attr_of ($;@) {
@@ -640,7 +652,7 @@ sub loginid (;$) {
    return untaint_cmdline( get_user( $_[ 0 ] )->name || 'unknown' );
 }
 
-sub logname (;$) { # Deprecated
+sub logname (;$) { # Deprecated use loginid
    return untaint_cmdline( $ENV{USER} || $ENV{LOGNAME} || loginid( $_[ 0 ] ) );
 }
 
@@ -648,7 +660,7 @@ sub merge_attributes ($$$;$) {
    my ($dest, $src, $defaults, $attrs) = @_; my $class = blessed $src;
 
    for (grep { not exists $dest->{ $_ } or not defined $dest->{ $_ } }
-        @{ $attrs || [] }) {
+        @{ $attrs // [] }) {
       my $v = $class ? ($src->can( $_ ) ? $src->$_() : undef) : $src->{ $_ };
 
       defined $v or $v = $defaults->{ $_ }; defined $v and $dest->{ $_ } = $v;
@@ -658,7 +670,7 @@ sub merge_attributes ($$$;$) {
 }
 
 sub my_prefix (;$) {
-   return split_on__( basename( $_[ 0 ] || q(), PERL_EXTNS ) );
+   return split_on__( basename( $_[ 0 ] // q(), PERL_EXTNS ) );
 }
 
 sub nonblocking_write_pipe_pair () {
@@ -705,25 +717,25 @@ sub socket_pair () {
 }
 
 sub split_on__ (;$$) {
-   return (split m{ _ }mx, $_[ 0 ] || q())[ $_[ 1 ] || 0 ];
+   return (split m{ _ }mx, $_[ 0 ] // q())[ $_[ 1 ] // 0 ];
 }
 
 sub split_on_dash (;$$) {
-   return (split m{ \- }mx, $_[ 0 ] || q())[ $_[ 1 ] || 0 ];
+   return (split m{ \- }mx, $_[ 0 ] // q())[ $_[ 1 ] // 0 ];
 }
 
 sub squeeze (;$) {
-   (my $v = $_[ 0 ] || q()) =~ s{ \s+ }{ }gmx; return $v;
+   (my $v = $_[ 0 ] // q()) =~ s{ \s+ }{ }gmx; return $v;
 }
 
 sub strip_leader (;$) {
-   (my $v = $_[ 0 ] || q()) =~ s{ \A [^:]+ [:] \s+ }{}msx; return $v;
+   (my $v = $_[ 0 ] // q()) =~ s{ \A [^:]+ [:] \s+ }{}msx; return $v;
 }
 
 sub sub_name (;$) {
-   my $frame = 1 + ($_[ 0 ] || 0);
+   my $frame = 1 + ($_[ 0 ] // 0);
 
-   return (split m{ :: }mx, ((caller $frame)[ 3 ]) || 'main')[ -1 ];
+   return (split m{ :: }mx, ((caller $frame)[ 3 ]) // 'main')[ -1 ];
 }
 
 sub sum (;@) {
@@ -759,7 +771,7 @@ sub throw_on_error (;@) {
 }
 
 sub trim (;$$) {
-   my $chs = $_[ 1 ] || " \t"; (my $v = $_[ 0 ] || q()) =~ s{ \A [$chs]+ }{}mx;
+   my $chs = $_[ 1 ] // " \t"; (my $v = $_[ 0 ] // q()) =~ s{ \A [$chs]+ }{}mx;
 
    chomp $v; $v =~ s{ [$chs]+ \z }{}mx; return $v;
 }
@@ -851,21 +863,21 @@ Provides globally accessible functions
 
 =head1 Subroutines/Methods
 
-=head2 abs_path
+=head2 C<abs_path>
 
    $absolute_untainted_path = abs_path $some_path;
 
 Untaints path. Makes it an absolute path and returns it. Returns undef
 otherwise. Traverses the filesystem
 
-=head2 app_prefix
+=head2 C<app_prefix>
 
    $prefix = app_prefix __PACKAGE__;
 
 Takes a class name and returns it lower cased with B<::> changed to
 B<_>, e.g. C<App::Munchies> becomes C<app_munchies>
 
-=head2 arg_list
+=head2 C<arg_list>
 
    $args = arg_list @rest;
 
@@ -873,7 +885,7 @@ Returns a hash ref containing the passed parameter list. Enables
 methods to be called with either a list or a hash ref as it's input
 parameters
 
-=head2 assert
+=head2 C<assert>
 
    assert $ioc_object, $condition, $message;
 
@@ -882,27 +894,27 @@ L<assert|Classs::Usul::Constants/ASSERT> constant can be set via
 an inherited class attribute to do something useful with whatever parameters
 are passed to it
 
-=head2 assert_directory
+=head2 C<assert_directory>
 
    $untainted_path = assert_directory $path_to_directory;
 
 Untaints directory path. Makes it an absolute path and returns it if it
 exists. Returns undef otherwise
 
-=head2 base64_decode_ns
+=head2 C<base64_decode_ns>
 
    $decoded_value = base64_decode_ns $encoded_value;
 
-Decode a scalar value encode using L<base64_encode_ns>
+Decode a scalar value encode using L</base64_encode_ns>
 
-=head2 base64_encode_ns
+=head2 C<base64_encode_ns>
 
    $encoded_value = base64_encode_ns $encoded_value;
 
 Base 64 encode a scalar value using an output character set that preserves
 the input values sort order (natural sort)
 
-=head2 bsonid
+=head2 C<bsonid>
 
    $bson_id = bsonid;
 
@@ -910,26 +922,26 @@ Generate a new C<BSON> id. Returns a 24 character string of hex digits that
 are reasonably unique across hosts and are in ascending order. Use this
 to create unique ids for data streams like message queues and file feeds
 
-=head2 bsonid_time
+=head2 C<bsonid_time>
 
    $seconds_elapsed_since_the_epoch = bsonid_time $bson_id;
 
 Returns the time the C<BSON> id was generated as Unix time
 
-=head2 bson64id
+=head2 C<bson64id>
 
    $base64_encoded_extended_bson64_id = bson64id;
 
 Like L</bsonid> but better thread long running process support. A custom
 Base64 encoding is used to reduce the id length
 
-=head2 bson64id_time
+=head2 C<bson64id_time>
 
    $seconds_elapsed_since_the_epoch = bson64id_time $bson64_id;
 
 Returns the time the C<BSON64> id was generated as Unix time
 
-=head2 build
+=head2 C<build>
 
    $code_ref = build { }, $code_ref;
 
@@ -937,7 +949,7 @@ Returns a code ref which when called returns the result of calling the block
 passing in the result of calling the optional code ref. Delays the calling
 of the input code ref until the output code ref is called
 
-=head2 canonicalise
+=head2 C<canonicalise>
 
    $untainted_canonpath = canonicalise $base, $relpath;
 
@@ -945,21 +957,28 @@ Appends C<$relpath> to C<$base> using L<File::Spec::Functions>. The C<$base>
 and C<$relpath> arguments can be an array reference or a scalar. The return
 path is untainted and canonicalised
 
-=head2 class2appdir
+=head2 C<chain>
+
+   $result = chain $sub1, $sub2, $sub3
+
+Call each sub in turn passing the returned value as the first argument to
+the next function call
+
+=head2 C<class2appdir>
 
    $appdir = class2appdir __PACKAGE__;
 
 Returns lower cased L</distname>, e.g. C<App::Munchies> becomes
 C<app-munchies>
 
-=head2 classdir
+=head2 C<classdir>
 
    $dir_path = classdir __PACKAGE__;
 
 Returns the path (directory) of a given class. Like L</classfile> but
 without the I<.pm> extension
 
-=head2 classfile
+=head2 C<classfile>
 
    $file_path = classfile __PACKAGE__ ;
 
@@ -967,7 +986,7 @@ Returns the path (file name plus extension) of a given class. Uses
 L<File::Spec> for portability, e.g. C<App::Munchies> becomes
 C<App/Munchies.pm>
 
-=head2 create_token
+=head2 C<create_token>
 
    $random_hex = create_token $optional_seed;
 
@@ -975,7 +994,7 @@ Create a random string token using L</digest>. If C<$seed> is defined then add
 that to the digest, otherwise add some random data provided by a call to
 L</urandom>. Returns a hexadecimal string
 
-=head2 curry
+=head2 C<curry>
 
    $curried_code_ref = curry $code_ref, @args;
    $result = $curried_code_ref->( @more_args );
@@ -985,19 +1004,25 @@ initial code reference passing in the original argument list and the
 arguments from the curried call. Must be called with a code reference and
 at least one argument
 
-=head2 dash2under
+=head2 C<cwdp>
+
+   $current_working_directory = cwdp;
+
+Returns the current working directory, physical location
+
+=head2 C<dash2under>
 
    $string_with_underscores = dash2under 'a-string-with-dashes';
 
 Substitutes underscores for dashes
 
-=head2 data_dumper
+=head2 C<data_dumper>
 
    data_dumper $thing;
 
 Uses L<Data::Printer> to dump C<$thing> in colour to I<stderr>
 
-=head2 digest
+=head2 C<digest>
 
    $digest_object = digest $seed;
 
@@ -1005,52 +1030,52 @@ Creates an instance of the first available L<Digest> class and adds the seed.
 The constant C<DIGEST_ALGORITHMS> is consulted for the list of algorithms to
 search for. Returns the digest object reference
 
-=head2 distname
+=head2 C<distname>
 
    $distname = distname __PACKAGE__;
 
 Takes a class name and returns it with B<::> changed to
 B<->, e.g. C<App::Munchies> becomes C<App-Munchies>
 
-=head2 elapsed
+=head2 C<elapsed>
 
    $elapsed_seconds = elapsed;
 
 Returns the number of seconds elapsed since the process started
 
-=head2 emit
+=head2 C<emit>
 
    emit @lines_of_text;
 
 Prints to I<STDOUT> the lines of text passed to it. Lines are C<chomp>ed
 and then have newlines appended. Throws on IO errors
 
-=head2 emit_err
+=head2 C<emit_err>
 
    emit_err @lines_of_text;
 
 Like L</emit> but output to C<STDERR>
 
-=head2 emit_to
+=head2 C<emit_to>
 
    emit_to $filehandle, @lines_of_text;
 
 Prints to the specified file handle
 
-=head2 ensure_class_loaded
+=head2 C<ensure_class_loaded>
 
    ensure_class_loaded $some_class, $options_ref;
 
 Require the requested class, throw an error if it doesn't load
 
-=head2 env_prefix
+=head2 C<env_prefix>
 
    $prefix = env_prefix $class;
 
 Returns upper cased C<app_prefix>. Suitable as prefix for environment
 variables
 
-=head2 escape_TT
+=head2 C<escape_TT>
 
    $text = escape_TT '[% some_stash_key %]';
 
@@ -1059,14 +1084,14 @@ less than symbol instead. Also replaces the right square bracket with
 greater than for balance. L<Template::Toolkit> will work with these
 sequences too, so unescaping isn't absolutely necessary
 
-=head2 exception
+=head2 C<exception>
 
    $e = exception $error;
 
 Expose the C<catch> method in the exception
 class L<Class::Usul::Exception>. Returns a new error object
 
-=head2 find_apphome
+=head2 C<find_apphome>
 
    $directory_path = find_apphome $appclass, $homedir, $extns
 
@@ -1084,31 +1109,31 @@ Returns the path to the applications home directory. Searches the following:
    # 5b. Config file found in @INC - dash as separator
    # 6.  Default to /tmp
 
-=head2 find_source
+=head2 C<find_source>
 
    $path = find_source $module_name;
 
 Find absolute path to the source code for the given module
 
-=head2 first_char
+=head2 C<first_char>
 
    $single_char = first_char $some_string;
 
 Returns the first character of C<$string>
 
-=head2 fold
+=head2 C<fold>
 
    *sum = fold { $a + $b } 0;
 
 Classic reduce function with optional base value
 
-=head2 fqdn
+=head2 C<fqdn>
 
    $domain_name = fqdn $hostname;
 
 Call C<gethostbyname> on the supplied hostname whist defaults to this host
 
-=head2 fullname
+=head2 C<fullname>
 
    $fullname = fullname;
 
@@ -1116,13 +1141,13 @@ Returns the untainted first sub field from the gecos attribute of the
 object returned by a call to L</get_user>. Returns the null string if
 the gecos attribute value is false
 
-=head2 get_cfgfiles
+=head2 C<get_cfgfiles>
 
    $paths = get_cfgfiles $appclass, $dirs, $extns
 
 Returns an array ref of configurations file paths for the application
 
-=head2 get_user
+=head2 C<get_user>
 
    $user_object = get_user $optional_uid_or_name;
 
@@ -1132,77 +1157,78 @@ package is loaded so objects are returned. On MSWin32 systems returns an
 instance of L<Class::Null>.  Defaults to the current uid but will lookup the
 supplied uid if provided
 
-=head2 hex2str
+=head2 C<hex2str>
 
    $string = hex2str $pairs_of_hex_digits;
 
 Converts the pairs of hex digits into a string of characters
 
-=head2 home2appldir
+=head2 C<home2appldir>
 
    $appldir = home2appldir $home_dir;
 
 Strips the trailing C<lib/my_package> from the supplied directory path
 
-=head2 io
+=head2 C<io>
 
    $io_object_ref = io $path_to_file_or_directory;
 
 Returns a L<File::DataClass::IO> object reference
 
-=head2 is_arrayref
+=head2 C<is_arrayref>
 
    $bool = is_arrayref $scalar_variable
 
 Tests to see if the scalar variable is an array ref
 
-=head2 is_coderef
+=head2 C<is_coderef>
 
    $bool = is_coderef $scalar_variable
 
 Tests to see if the scalar variable is a code ref
 
-=head2 is_hashref
+=head2 C<is_hashref>
 
    $bool = is_hashref $scalar_variable
 
 Tests to see if the scalar variable is a hash ref
 
-=head2 is_member
+=head2 C<is_member>
 
    $bool = is_member 'test_value', qw( a_value test_value b_value );
 
 Tests to see if the first parameter is present in the list of
 remaining parameters
 
-=head2 is_ntfs
+=head2 C<is_ntfs>
 
    $bool = is_ntfs;
 
 Returns true if L</is_win32> is true or the C<$OSNAME> is
 L<cygwin|File::DataClass::Constants/CYGWIN>
 
-=head2 is_win32
+=head2 C<is_win32>
 
    $bool = is_win32;
 
-Returns true if the C<$OSNAME> is L<evil|File::DataClass::Constants/MSOFT>
+Returns true if the C<$OSNAME> is
+L<unfortunate|File::DataClass::Constants/MSOFT>
 
-=head2 list_attr_of
+=head2 C<list_attr_of>
 
    $attribute_list = list_attr_of $object_ref, @exception_list;
 
 Lists the attributes of the object reference, including defining class name,
 documentation, and current value
 
-=head2 loginid
+=head2 C<loginid>
 
    $loginid = loginid;
 
 Returns the untainted name attribute of the object returned by a call
 to L</get_user> or 'unknown' if the name attribute value is false
 
-=head2 logname
+=head2 C<logname>
 
    $logname = logname;
 
@@ -1210,7 +1236,7 @@ Deprecated. Returns untainted the first true value returned by; the environment
 variable C<USER>, the environment variable C<LOGNAME>, and the function
 L</loginid>
 
-=head2 merge_attributes
+=head2 C<merge_attributes>
 
    $dest = merge_attributes $dest, $src, $defaults, $attr_list_ref;
 
@@ -1219,14 +1245,14 @@ C<$dest> hash values take precedence over the C<$src> hash values which
 take precedence over the C<$defaults> hash values. The C<$src> hash
 may be an object in which case its accessor methods are called
 
-=head2 nonblocking_write_pipe_pair
+=head2 C<nonblocking_write_pipe_pair>
 
    $array_ref = non_blocking_write_pipe;
 
 Returns a pair of file handles, read then write. The write file handle is
 non blocking, binmode is set on both
 
-=head2 my_prefix
+=head2 C<my_prefix>
 
    $prefix = my_prefix $PROGRAM_NAME;
 
@@ -1234,7 +1260,7 @@ Takes the basename of the supplied argument and returns the first _
 (underscore) separated field. Supplies basename with
 L<extensions|Class::Usul::Constants/PERL_EXTNS>
 
-=head2 pad
+=head2 C<pad>
 
    $padded_str = pad $unpadded_str, $wanted_length, $pad_char, $direction;
 
@@ -1242,65 +1268,65 @@ Pad a string out to the wanted length with the C<$pad_char> which
 defaults to a space. Direction can be; I<both>, I<left>, or I<right>
 and defaults to I<right>
 
-=head2 prefix2class
+=head2 C<prefix2class>
 
    $class = prefix2class $PROGRAM_NAME;
 
 Calls L</my_prefix> with the supplied argument, splits the result on dash,
 C<ucfirst>s the list and then C<join>s that with I<::>
 
-=head2 product
+=head2 C<product>
 
    $product = product 1, 2, 3, 4;
 
 Returns the product of the list of numbers
 
-=head2 socket_pair
+=head2 C<socket_pair>
 
    ($reader, $writer) = @{ socket_pair };
 
 Return a C<socketpair> reader then writer. The writer has been closed on the
 reader and the reader has been closed on the writer
 
-=head2 split_on__
+=head2 C<split_on__>
 
    $field = split_on__ $string, $field_no;
 
 Splits string by _ (underscore) and returns the requested field. Defaults
 to field zero
 
-=head2 split_on_dash
+=head2 C<split_on_dash>
 
    $field = split_on_dash $string, $field_no;
 
 Splits string by - (dash) and returns the requested field. Defaults
 to field zero
 
-=head2 squeeze
+=head2 C<squeeze>
 
    $string = squeeze $string_containing_muliple_spacesd;
 
 Squeezes multiple whitespace down to a single space
 
-=head2 strip_leader
+=head2 C<strip_leader>
 
    $stripped = strip_leader 'my_program: Error message';
 
 Strips the leading "program_name: whitespace" from the passed argument
 
-=head2 sub_name
+=head2 C<sub_name>
 
    $sub_name = sub_name $level;
 
 Returns the name of the method that calls it
 
-=head2 sum
+=head2 C<sum>
 
    $total = sum 1, 2, 3, 4;
 
 Adds the list of values
 
-=head2 symlink
+=head2 C<symlink>
 
    $message = symlink $from, $to, $base;
 
@@ -1308,13 +1334,13 @@ It creates a symlink. If either C<$from> or C<$to> is a relative path
 then C<$base> is prepended to make it absolute. Returns a message
 indicating success or throws an exception on failure
 
-=head2 thread_id
+=head2 C<thread_id>
 
    $tid = thread_id;
 
 Returns the id of this thread. Returns zero if threads are not loaded
 
-=head2 throw
+=head2 C<throw>
 
    throw error => 'error_key', args => [ 'error_arg' ];
 
@@ -1322,7 +1348,7 @@ Expose L<Class::Usul::Exception/throw>. L<Class::Usul::Constants> has a
 class attribute I<Exception_Class> which can be set change the class
 of the thrown exception
 
-=head2 throw_on_error
+=head2 C<throw_on_error>
 
    throw_on_error @args;
 
@@ -1330,7 +1356,7 @@ Passes it's optional arguments to L</exception> and if an exception object is
 returned it throws it. Returns undefined otherwise. If no arguments are
 passed L</exception> will use the value of the global C<$EVAL_ERROR>
 
-=head2 trim
+=head2 C<trim>
 
    $trimmed_string = trim $string_with_leading_and_trailing_whitespace;
 
@@ -1338,40 +1364,40 @@ Remove leading and trailing whitespace including trailing newlines. Takes
 an additional string used as the character class to remove. Defaults to
 space and tab
 
-=head2 unescape_TT
+=head2 C<unescape_TT>
 
    $text = unescape_TT '<% some_stash_key %>';
 
 Do the reverse of C<escape_TT>
 
-=head2 untaint_cmdline
+=head2 C<untaint_cmdline>
 
    $untainted_cmdline = untaint_cmdline $maybe_tainted_cmdline;
 
 Returns an untainted command line string. Calls L</untaint_string> with the
 matching regex from L<Class::Usul::Constants>
 
-=head2 untaint_identifier
+=head2 C<untaint_identifier>
 
    $untainted_identifier = untaint_identifier $maybe_tainted_identifier;
 
 Returns an untainted identifier string. Calls L</untaint_string> with the
 matching regex from L<Class::Usul::Constants>
 
-=head2 untaint_path
+=head2 C<untaint_path>
 
    $untainted_path = untaint_path $maybe_tainted_path;
 
 Returns an untainted file path. Calls L</untaint_string> with the
 matching regex from L<Class::Usul::Constants>
 
-=head2 untaint_string
+=head2 C<untaint_string>
 
    $untainted_string = untaint_string $regex, $maybe_tainted_string;
 
 Returns an untainted string or throws
 
-=head2 urandom
+=head2 C<urandom>
 
    $bytes = urandom $optional_length, $optional_provider;
 
@@ -1380,13 +1406,13 @@ F</dev/urandom> and can be any type accepted by L</io>. If the provider exists
 and is readable, length bytes are read from it and returned. Otherwise some
 bytes from the second best generator are returned
 
-=head2 uuid
+=head2 C<uuid>
 
    $uuid = uuid $optional_uuid_proc_filesystem_path;
 
 Return the contents of F</proc/sys/kernel/random/uuid>
 
-=head2 whiten
+=head2 C<whiten>
 
    $encoded = whiten 'plain_text_to_be_obfuscated';
 
@@ -1395,7 +1421,7 @@ tabs, and newlines. The L<encrypt> and L<decrypt> functions take a seed
 attribute in their options hash reference. A whitened line of Perl code
 would be a suitable value
 
-=head2 zip
+=head2 C<zip>
 
    %hash = zip @list_of_keys, @list_of_values;
 
